@@ -53,11 +53,11 @@
 #include <gpe/spacing.h>
 #include <gpe/gpe-iconlist.h>
 #include <gpe/tray.h>
+#include <gpe/launch.h>
 
 /* everything else */
 #include "main.h"
 #include "cfg.h"
-#include "launch.h"
 #include "tray.h"
 
 //#define DEBUG
